Home
last modified time | relevance | path

Searched refs:__offset (Results 1 – 17 of 17) sorted by relevance

/freebsd-12.1/contrib/llvm/tools/clang/lib/Headers/
H A D__clang_cuda_intrinsics.h39 inline __device__ int __FnName(int __val, __Type __offset, \
41 return __IntIntrinsic(__val, __offset, \
44 inline __device__ float __FnName(float __val, __Type __offset, \
46 return __FloatIntrinsic(__val, __offset, \
49 inline __device__ unsigned int __FnName(unsigned int __val, __Type __offset, \
52 ::__FnName(static_cast<int>(__val), __offset, __width)); \
54 inline __device__ long long __FnName(long long __val, __Type __offset, \
63 __tmp.__a = ::__FnName(__tmp.__a, __offset, __width); \
64 __tmp.__b = ::__FnName(__tmp.__b, __offset, __width); \
69 inline __device__ long __FnName(long __val, __Type __offset, \
[all …]
H A Dvecintrin.h860 vec_xl(long __offset, const signed char *__ptr) { in vec_xl() argument
865 vec_xl(long __offset, const unsigned char *__ptr) { in vec_xl() argument
870 vec_xl(long __offset, const signed short *__ptr) { in vec_xl() argument
880 vec_xl(long __offset, const signed int *__ptr) { in vec_xl() argument
885 vec_xl(long __offset, const unsigned int *__ptr) { in vec_xl() argument
901 vec_xl(long __offset, const float *__ptr) { in vec_xl() argument
907 vec_xl(long __offset, const double *__ptr) { in vec_xl() argument
915 vec_xld2(long __offset, const signed char *__ptr) { in vec_xld2() argument
939 vec_xld2(long __offset, const signed int *__ptr) { in vec_xld2() argument
963 vec_xld2(long __offset, const double *__ptr) { in vec_xld2() argument
[all …]
H A Daltivec.h16373 return *(unaligned_vec_uchar*)(__ptr + __offset); in vec_xl()
16388 return *(unaligned_vec_sint *)(__ptr + __offset); in vec_xl()
16393 return *(unaligned_vec_uint *)(__ptr + __offset); in vec_xl()
16408 return *(unaligned_vec_sll *)(__ptr + __offset); in vec_xl()
16413 return *(unaligned_vec_ull *)(__ptr + __offset); in vec_xl()
16501 return vec_xl(__offset, __ptr); in vec_xl_be()
16506 return vec_xl(__offset, __ptr); in vec_xl_be()
16561 *(unaligned_vec_sll *)(__ptr + __offset) = __vec; in vec_xst()
16567 *(unaligned_vec_ull *)(__ptr + __offset) = __vec; in vec_xst()
16670 vec_xst(__vec, __offset, __ptr); in vec_xst_be()
[all …]
/freebsd-12.1/contrib/compiler-rt/lib/asan/
H A Dasan_interceptors_memintrinsics.h54 uptr __offset = (uptr)(offset); \ in DECLARE_REAL()
57 if (__offset > __offset + __size) { \ in DECLARE_REAL()
59 ReportStringFunctionSizeOverflow(__offset, __size, &stack); \ in DECLARE_REAL()
61 if (!QuickCheckForUnpoisonedRegion(__offset, __size) && \ in DECLARE_REAL()
62 (__bad = __asan_region_is_poisoned(__offset, __size))) { \ in DECLARE_REAL()
/freebsd-12.1/contrib/libstdc++/include/debug/
H A Dvector268 difference_type __offset = __position - begin();
273 this->_M_invalidate_if(_After_nth(__offset, _M_base().begin()));
283 difference_type __offset = __position - begin();
288 this->_M_invalidate_if(_After_nth(__offset, _M_base().begin()));
303 difference_type __offset = __position - begin();
309 this->_M_invalidate_if(_After_nth(__offset, _M_base().begin()));
317 difference_type __offset = __position - begin();
319 this->_M_invalidate_if(_After_nth(__offset, _M_base().begin()));
330 difference_type __offset = __first - begin();
333 this->_M_invalidate_if(_After_nth(__offset, _M_base().begin()));
/freebsd-12.1/contrib/libc++/include/
H A Dspan303 subspan(index_type __offset, index_type __count = dynamic_extent) const noexcept
305 …_LIBCPP_ASSERT( __offset >= 0 && __offset <= size(), "Offset out of range in span::subspan(offset,…
308 return {data() + __offset, size() - __offset};
309 …_LIBCPP_ASSERT(__offset + __count <= size(), "count + offset out of range in span::subspan(offset,…
310 return {data() + __offset, __count};
468 subspan(index_type __offset, index_type __count = dynamic_extent) const noexcept
470 …_LIBCPP_ASSERT( __offset >= 0 && __offset <= size(), "Offset out of range in span::subspan(offset,…
473 return {data() + __offset, size() - __offset};
474 …_LIBCPP_ASSERT(__offset + __count <= size(), "Offset + count out of range in span::subspan(offset,…
475 return {data() + __offset, __count};
H A Dregex5907 int __offset = (__flags & regex_constants::match_prev_avail) ? 1 : 0;
5908 basic_string<_CharT> __s(_VSTD::prev(__first, __offset), __last);
5910 bool __r = __e.__search(__s.data() + __offset, __s.data() + __s.size(), __mc, __flags);
/freebsd-12.1/contrib/libstdc++/include/std/
H A Dstd_bitset.h222 const size_t __offset = __shift % _GLIBCXX_BITSET_BITS_PER_WORD; in _M_do_left_shift() local
224 if (__offset == 0) in _M_do_left_shift()
230 - __offset); in _M_do_left_shift()
232 _M_w[__n] = ((_M_w[__n - __wshift] << __offset) in _M_do_left_shift()
234 _M_w[__wshift] = _M_w[0] << __offset; in _M_do_left_shift()
248 const size_t __offset = __shift % _GLIBCXX_BITSET_BITS_PER_WORD; in _M_do_right_shift() local
251 if (__offset == 0) in _M_do_right_shift()
257 - __offset); in _M_do_right_shift()
259 _M_w[__n] = ((_M_w[__n + __wshift] >> __offset) in _M_do_right_shift()
261 _M_w[__limit] = _M_w[_Nw-1] >> __offset; in _M_do_right_shift()
/freebsd-12.1/contrib/libstdc++/include/bits/
H A Dstl_deque.h185 const difference_type __offset = __n + (_M_cur - _M_first); member
186 if (__offset >= 0 && __offset < difference_type(_S_buffer_size()))
191 __offset > 0 ? __offset / difference_type(_S_buffer_size())
192 : -difference_type((-__offset - 1)
195 _M_cur = _M_first + (__offset - __node_offset
/freebsd-12.1/include/
H A Dnl_types.h75 int32_t __offset; member
/freebsd-12.1/contrib/libstdc++/libsupc++/
H A Dtinfo.cc322 ptrdiff_t offset = __base_info[i].__offset (); in __do_find_public_src()
448 ptrdiff_t offset = __base_info[i].__offset (); in __do_dyncast()
643 ptrdiff_t offset = __base_info[i].__offset (); in __do_upcast()
H A Dcxxabi.h327 __offset() const in __offset() function
/freebsd-12.1/contrib/compiler-rt/lib/msan/
H A Dmsan_interceptors.cc104 sptr __offset = __msan_test_shadow(x, n); \
106 if (__offset >= 0 && __msan::flags()->report_umrs) { \
109 ReportUMRInsideAddressRange(__func__, x, n, __offset); \
111 pc, bp, __msan_get_origin((const char *)x + __offset)); \
/freebsd-12.1/lib/libc/nls/
H A Dmsgcat.c303 msg_hdr[i].__offset)); in catgets()
/freebsd-12.1/usr.bin/gencat/
H A Dgencat.c560 msg_hdr->__offset = htonl(msg_offset);
/freebsd-12.1/contrib/gcc/cp/
H A DChangeLog-20004038 (__base_class_info::__offset): Use a static_cast.
4397 (__base_class_info::__offset): Comment shift.
/freebsd-12.1/contrib/gcc/
H A DFSFChangeLog.105423 * va-alpha.h (__gnuc_va_list): Make __offset an int.
5425 of __offset both both OSF and WINNT.